@@ -1,5 +1,6 @@
 from .HistoryMatch import HistoryMatch
 from .LayeredMap import LayeredMap
+from .LeafletMap import LeafletMap
 from .Map import Map
 from .Morris import Morris
 from .PriorPosteriorDistribution import PriorPosteriorDistribution
@@ -7,6 +8,7 @@ from .PriorPosteriorDistribution import PriorPosteriorDistribution
 __all__ = [
     "HistoryMatch",
     "LayeredMap",
+    "LeafletMap",
     "Map",
     "Morris",
     "PriorPosteriorDistribution"
